Result<O, E> class
sealed
Represents either a Success Ok or an Error Err
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isErr → bool
-
is err?
no setter
- isOk → bool
-
is ok?
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unwrap → O
-
Unwraps the value of a possible Ok, in case of Err it will throw an State Error
no setter
- unwrapErr → E
-
Unwraps the value of a possible Err, in case of Ok it will throw an State Error
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retag<
O2> () → Result< O2, E> -
Returns a new Result with the same error type
Ebut a different success typeO2, only if this result is an Err. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited